@@ -43,27 +43,27 @@ def d3graph(adjmat, df=None, node_name=None, node_color='#000080', node_color_ed
         Label name for the nodes, e.g., ['1','2','3',...]
     node_color : list of strings (default : '#000080')
         Color of the node.
-        None: Do something style: All nodes will be have the same color (auto generated).
-        ['A']: Lazy  style: All nodes will have hte same color. Color is generated on CMAP and the unique labels.
-        ['#000000']: Lazy+ style: All nodes will have the same hex color.
-        ['A','A','B',...]: Pro   style: Colors are generated using cmap and the unique labels recordingly colored.
-        ['#377eb8','#ffffff','#000000',...]: Pro+  style:        Hex colors are directly used.
+        * None: Do something style: All nodes will be have the same color (auto generated).
+        * ['A']: All nodes will have hte same color. Color is generated on CMAP and the unique labels.
+        * ['#000000']: All nodes will have the same hex color.
+        * ['A','A','B',...]:  Colors are generated using cmap and the unique labels recordingly colored.
+        * ['#377eb8','#ffffff','#000000',...]: Hex colors are directly used.
     node_color_edge : list of strings (default : '#000080')
         See node_color.
     node_size : array of integers (default=5)
         Size of the node edge., e.g.,  None 10: All nodes will be set on this size, [2,5,1,...]  Specify per node the size
     node_size_edge : array of integers (default : 1)
         Size of the node edge. Note that node edge sizes are automatically scaled between [0.1 - 4].
-        10: All nodes will be set on this size,
-        [2,5,1,...]  Specify per node the edge size.
+        * 10: All nodes will be set on this size,
+        * [2,5,1,...]  Specify per node the edge size.
     edge_width : float (default: None)
         width of the edges.
-        None: The values in the data are rescaled between [1-10] and used for the width.
-        1: all values have the same width
+        * None: The values in the data are rescaled between [1-10] and used for the width.
+        * 1: all values have the same width
     edge_distance : Int (default: None)
         Distance of nodes on the edges.
-        0: Weighted approach using edge weights in the adjadancy matrix. Weights are normalized between the edge_distance_minmax
-        80: Constant edge distance
+        * 0: Weighted approach using edge weights in the adjadancy matrix. Weights are normalized between the edge_distance_minmax
+        * 80: Constant edge distance
 
     NETWORK BEHAVOIR SETTINGS
     --------------------------
@@ -86,7 +86,17 @@ def d3graph(adjmat, df=None, node_name=None, node_color='#000080', node_color_ed
         Title of the figure.
     cmap : String, (default: 'Set1')
         All colors can be reversed with '_r', e.g. 'binary' to 'binary_r'
-        'Set1','Set2','rainbow','bwr','binary','seismic','Blues','Reds','Pastel1','Paired','Set1'
+        * 'Set1'
+        * 'Set2'
+        * 'rainbow'
+        * 'bwr'
+        * 'binary'
+        * 'seismic'
+        * 'Blues'
+        * 'Reds'
+        * 'Pastel1'
+        * 'Paired'
+        * 'Set1'
     slider : typle [int, int]:, (default: [0,10])
         Slider to break the network on edge-strength, e.g. set slider in range 0 to 10
     savepath : String, (Default: user temp directory)
@@ -159,7 +169,7 @@ def d3graph(adjmat, df=None, node_name=None, node_color='#000080', node_color_ed
 
     """
     # Checks
-    adjmat = _do_checks(adjmat)
+    adjmat = _do_checks(adjmat.copy())
     # Parameters
     config = _set_configurations(width, height, collision, charge, edge_distance_minmax, edge_distance, edge_width, directed, title, slider, savepath, savename, cmap, showfig, verbose)
     # Make node configurations
@@ -194,7 +204,7 @@ def d3graph(adjmat, df=None, node_name=None, node_color='#000080', node_color_ed
 def _setup_slider(G, slider=None):
     tmplist = [*G.edges.values()]
     edge_weight = []
-    for i in range(0,len(tmplist)):
+    for i in range(0, len(tmplist)):
         edge_weight = np.append(edge_weight, tmplist[i]['edge_weight'])
 
     if slider is None:
@@ -244,7 +254,7 @@ def _write_json(G, config):
     nodes = pd.DataFrame([*G.nodes.values()]).T.to_dict()
     nodeid = [*G.nodes]
     nodes_new = [None] * len(nodes)
-    for i in range(0,len(nodes)):
+    for i in range(0, len(nodes)):
         nodes_new[int(nodeid[i])] = nodes[i]
     data['nodes'] = nodes_new
 
@@ -273,7 +283,7 @@ def _write_index_html(config, jsonpath):
     f.write('<script type="application/json" id="d3graph"> {\n')
 
     # Write graph
-    fs = open(jsonpath,'r')
+    fs = open(jsonpath, 'r')
     lines = fs.readlines()[1:]
     for line in lines:
         f.write(line)
@@ -306,7 +316,7 @@ def _write_jscript(df, config):
         d3graphscript = file.read()
 
     # Create hover-over textbox for the nodes
-    idx = np.where(df.columns.str.contains('node_') is False)[0]
+    idx = np.where(df.columns.str.contains('node_')==False)[0]
     idx = np.append(idx, np.where(df.columns == 'node_name')[0])
     HOVEROVER = ''
     DIRECTED_LINKS = '//'
@@ -320,8 +330,11 @@ def _write_jscript(df, config):
         str_middle = ''
         for i in range(0, len(idx)):
             str_middle = str_middle + ('+ "\\n" + "' + df.columns[idx[i]] + ': " + d.' + df.columns[idx[i]] + ' ')
+            # str_middle = str_middle + (df.columns[idx[i]] + ': " + d.' + df.columns[idx[i]] + '+ "\\n" + "')
+        str_middle = str_middle[9:]
 
-        str_start = 'function(d) { return "Node: " + d.id '
+        # str_start = 'function(d) { return "Node: " + d.id '
+        str_start = 'function(d) { return '
         str_end = ';}'
         HOVEROVER = str_start + str_middle + str_end
 
@@ -356,7 +369,8 @@ def _node_config(df, node_name, node_color, node_size, node_size_edge, node_colo
         pass
     elif isinstance(node_name, str):
         node_name = np.array([node_name] * nodecount)
-    elif isinstance(adjmat, type(None)) is False:
+    # elif isinstance(adjmat, type(None)) is False:
+    elif adjmat is not None:
         node_name = adjmat.columns.astype(str)
     else:
         node_name = np.array([''] * nodecount)
@@ -432,8 +446,8 @@ def _node_config(df, node_name, node_color, node_size, node_size_edge, node_colo
     df['node_color_edge']=node_color_edge
     # Make strings of the identifiers
     df.index=df.index.astype(str)
-    df.columns=df.columns.str.replace(' ','_')
-    df.columns=df.columns.str.replace('.','_')
+    df.columns=df.columns.str.replace(' ', '_')
+    df.columns=df.columns.str.replace('.', '_')
 
     return(df)
 
@@ -464,14 +478,14 @@ def adjmat2G(adjmat, df, edge_distance_min=None, edge_distance_max=None, edge_wi
     node_names = adjmat.index.values
     adjmat.reset_index(drop=True, inplace=True)
     adjmat.index = adjmat.index.values.astype(str)
-    adjmat.columns = np.arange(0,adjmat.shape[1]).astype(str)
+    adjmat.columns = np.arange(0, adjmat.shape[1]).astype(str)
     adjmat = adjmat.stack().reset_index()
     adjmat.columns = ['source', 'target', 'weight']
 
     # Width of edge, scale between [1-10] if there is are more then 2 diferent weights
     if isinstance(edge_width, type(None)):
-        if len(np.unique(adjmat['weight'].values.reshape(-1,1)))>2:
-            adjmat['edge_width'] = _normalize_size(adjmat['weight'].values.reshape(-1,1), 1, 20)
+        if len(np.unique(adjmat['weight'].values.reshape(-1, 1)))>2:
+            adjmat['edge_width'] = _normalize_size(adjmat['weight'].values.reshape(-1, 1), 1, 20)
         else:
             edge_width=1
     if not isinstance(edge_width, type(None)):
@@ -479,34 +493,34 @@ def adjmat2G(adjmat, df, edge_distance_min=None, edge_distance_max=None, edge_wi
 
     # Scale the weights towards an edge weight
     if not isinstance(edge_distance_min, type(None)):
-        adjmat['edge_weight'] = _normalize_size(adjmat['weight'].values.reshape(-1,1), edge_distance_min, edge_distance_max)
+        adjmat['edge_weight'] = _normalize_size(adjmat['weight'].values.reshape(-1, 1), edge_distance_min, edge_distance_max)
     else:
-        adjmat['edge_weight'] = adjmat['weight'].values.reshape(-1,1)
+        adjmat['edge_weight'] = adjmat['weight'].values.reshape(-1, 1)
 
     # Keep only edges with weight
-    edge_weight_original = adjmat['weight'].values.reshape(-1,1).flatten()
-    adjmat = adjmat.loc[edge_weight_original > 0,:].reset_index(drop=True)
+    edge_weight_original = adjmat['weight'].values.reshape(-1, 1).flatten()
+    adjmat = adjmat.loc[edge_weight_original > 0, :].reset_index(drop=True)
 
     # Remove self-loops
-    I = adjmat['source'] != adjmat['target']
-    adjmat = adjmat.loc[I,:].reset_index(drop=True)
+    Iloc = adjmat['source'] != adjmat['target']
+    adjmat = adjmat.loc[Iloc, :].reset_index(drop=True)
 
     # Include source-target label
-    source_label = np.repeat('',adjmat.shape[0]).astype('O')
-    target_label = np.repeat('',adjmat.shape[0]).astype('O')
-    for i in range(0,len(node_names)):
+    source_label = np.repeat('', adjmat.shape[0]).astype('O')
+    target_label = np.repeat('', adjmat.shape[0]).astype('O')
+    for i in range(0, len(node_names)):
         source_label[adjmat['source']==str(i)] = node_names[i]
-    for i in range(0,len(node_names)):
+    for i in range(0, len(node_names)):
         target_label[adjmat['target']==str(i)] = node_names[i]
     adjmat['source_label'] = source_label
     adjmat['target_label'] = target_label
 
     # Make sure indexing of nodes is correct with the edges.
     uilabels = np.unique(np.append(adjmat['source'], adjmat['target']))
-    tmplabels=adjmat[['source','target']]
+    tmplabels=adjmat[['source', 'target']]
     adjmat['source']=None
     adjmat['target']=None
-    for i in range(0,len(uilabels)):
+    for i in range(0, len(uilabels)):
         I1 = tmplabels['source']==uilabels[i]
         I2 = tmplabels['target']==uilabels[i]
         adjmat['source'].loc[I1] = str(i)
